Package: LymphoSeq
Title: Analyze high-throughput sequencing of T and B cell receptors
Version: 1.39.0
Author: David Coffey <dcoffey@fredhutch.org>
Maintainer: David Coffey <dcoffey@fredhutch.org>
Description: This R package analyzes high-throughput sequencing of T
        and B cell receptor complementarity determining region 3 (CDR3)
        sequences generated by Adaptive Biotechnologies' ImmunoSEQ
        assay.  Its input comes from tab-separated value (.tsv) files
        exported from the ImmunoSEQ analyzer.
Depends: R (>= 3.3), LymphoSeqDB
Imports: data.table, plyr, dplyr, reshape, VennDiagram, ggplot2, ineq,
        RColorBrewer, circlize, grid, utils, stats, ggtree, msa,
        Biostrings, phangorn, stringdist, UpSetR
License: Artistic-2.0
RoxygenNote: 6.0.1
Suggests: knitr, pheatmap, wordcloud, rmarkdown
VignetteBuilder: knitr
biocViews: Software, Technology, Sequencing, TargetedResequencing,
        Alignment, MultipleSequenceAlignment
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/LymphoSeq
git_branch: devel
git_last_commit: be99fc7
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
Packaged: 2025-10-31 22:33:24 UTC; biocbuild
